"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMultiSelect = void 0;
var tslib_1 = require("tslib");
var react_1 = require("react");
var lodash_1 = tslib_1.__importDefault(require("lodash"));
var useMultiSelect = function () {
    var _a = react_1.useState({}), objStore = _a[0], setObjStore = _a[1];
    var _b = react_1.useState([]), storeKeys = _b[0], setStoreKeys = _b[1];
    var _c = react_1.useState([]), selectedKeys = _c[0], setSelectedKeys = _c[1];
    var hasKey = react_1.useCallback(function (key) { return lodash_1.default.has(objStore, key); }, [objStore]);
    var addObjToStore = react_1.useCallback(function (obj, keyPrefix) {
        if (keyPrefix === void 0) { keyPrefix = ""; }
        var key = "" + lodash_1.default.toString(Date.now());
        if (keyPrefix)
            key = keyPrefix + "_" + key;
        setObjStore(function (prevStore) {
            var _a;
            return (tslib_1.__assign(tslib_1.__assign({}, prevStore), (_a = {}, _a[key] = obj, _a)));
        });
        setStoreKeys(function (prevKeys) { return lodash_1.default.uniq(tslib_1.__spreadArray(tslib_1.__spreadArray([], prevKeys), [key])); });
        return key;
    }, [setObjStore, setStoreKeys]);
    var delObjFromStore = react_1.useCallback(function (key) {
        setObjStore(function (prevStore) { return lodash_1.default.omit(prevStore, key); });
        setStoreKeys(function (prevState) { return lodash_1.default.pull(prevState, key); });
        setSelectedKeys(function (prevState) { return lodash_1.default.pull(prevState, key); });
    }, [setObjStore, setStoreKeys, setSelectedKeys]);
    var delAllObjs = react_1.useCallback(function () {
        setObjStore({});
        setStoreKeys([]);
        setSelectedKeys([]);
    }, [setObjStore, setStoreKeys, setSelectedKeys]);
    var selectObj = react_1.useCallback(function (key) {
        if (hasKey(key))
            setSelectedKeys(function (prevState) { return lodash_1.default.uniq(tslib_1.__spreadArray(tslib_1.__spreadArray([], prevState), [key])); });
    }, [setSelectedKeys, hasKey]);
    var unSelectObj = react_1.useCallback(function (key) {
        setSelectedKeys(function (prevState) { return lodash_1.default.uniq(lodash_1.default.pull(tslib_1.__spreadArray([], prevState), key)); });
    }, [setSelectedKeys]);
    var selectAll = react_1.useCallback(function () {
        setSelectedKeys(storeKeys);
    }, [setSelectedKeys, storeKeys]);
    var unSelectAll = react_1.useCallback(function () {
        setSelectedKeys([]);
    }, [setSelectedKeys]);
    return {
        objStore: objStore,
        storeKeys: storeKeys,
        selectedKeys: selectedKeys,
        addObjToStore: addObjToStore,
        delObjFromStore: delObjFromStore,
        delAllObjs: delAllObjs,
        selectObj: selectObj,
        unSelectObj: unSelectObj,
        selectAll: selectAll,
        unSelectAll: unSelectAll,
    };
};
exports.useMultiSelect = useMultiSelect;
